@@ -1,3 +1,3 @@
-iso3166ud <- read.table(file='iso3166ud.txt', sep=';', header=TRUE, comment.char='#', na.strings="")
+iso3166ud <- utils::read.table(file='iso3166ud.txt', sep=';', header=TRUE, comment.char='#', na.strings="")
 colnames(iso3166ud) <- c('name', 'charcode', 'charcode3', 'uncode')
 iso3166ud <- cbind(iso3166ud, is.country=FALSE)
\ No newline at end of file
